
# ikos
Get the best price for Ikos Resorts.

# Usage
```
define holiday_price fhempy ikos FROMDATE TODATE
```

FROMDATE: YYYY-MM-DD e.g. 2023-10-01
TODATE: YYYY-MM-DD e.g. 2023-11-01

Example
```
define holiday_price fhempy ikos 2023-10-01 2023-11-01
```
